
NIFTy user guide
================

This guide is an overview and explains the main idea behind NIFTy.
More details on the API can be found at the `API reference <../mod/nifty8.html>`_.
In the following, an online version of the latest publication describing NIFTy is provided.
The publication gives a quick overview of the core concepts powering NIFTy and showcases a simple example:

.. toctree::
   :maxdepth: 1

   paper

The demonstration scripts which are part of NIFTy usually provide a good foundation for new projects in NIFTy:

.. toctree::
   :maxdepth: 1

   0_intro

In-depth discussion of important concepts in NIFTy and details on how to cite NIFTy is provided on the following pages:

.. toctree::
   :maxdepth: 1

   ift
   approximate_inference
   citations

In the following are guides to the old NIFTy.
They serve as reference but are likely not relevant anymore for new projects.

.. toctree::
   :maxdepth: 1

   old_nifty
   old_nifty_volume
   old_nifty_design_principles
   old_nifty_custom_nonlinearities
   old_nifty_getting_started_0
   old_nifty_getting_started_4_CorrelatedFields
